==> haskell-test-framework-hunit-0.3.0.2-1126.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-6aaATLwpnqw3PPYB2HkLCt
key:                  test-framework-hunit-0.3.0.2-6aaATLwpnqw3PPYB2HkLCt
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  586456aa2f8dd8e204cec93ea069554a
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-6aaATLwpnqw3PPYB2HkLCt
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om base-4.18.2.1
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    test-framework-0.8.2.2-ITHWZraIqyRCzzqSShCGFx

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-1130-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-2872p9r6J3I6VKD17s7qNh
key:                  test-framework-hunit-0.3.0.2-2872p9r6J3I6VKD17s7qNh
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  1cccc293d06beba4315c0b3b7e4b3615
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-2872p9r6J3I6VKD17s7qNh
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    test-framework-0.8.2.2-8fX8NEZ5OtDCOpAj0ijyRX

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
